pub struct Host { /* private fields */ }Expand description
The T in Store<T> for what the CLI is running.
This structures has a number of contexts used for various WASI proposals.
Note that all of them are optional meaning that they’re None by default
and enabled with various CLI flags (some CLI flags are on-by-default).