Struct wasmtime_cli::WasiModules [−][src]
Select which WASI modules are available at runtime for use by Wasm programs.
Fields
wasi_common: boolEnable the wasi-common implementation; eventually this should be split into its separate parts once the implementation allows for it (e.g. wasi-fs, wasi-clocks, etc.).
wasi_nn: boolEnable the experimental wasi-nn implementation.
wasi_crypto: boolEnable the experimental wasi-crypto implementation.
Implementations