pub struct HotBlocksCommand { /* private fields */ }Expand description
Profile a WebAssembly module or component’s execution and print the hottest basic blocks.
This command compiles the given Wasm module/component, runs it under perf record, and then analyzes the resulting profile to find the hottest basic
blocks in the compiled code. Each basic block is printed with its assembly,
CLIF IR, and original Wasm instructions.
This subcommand is only available on Linux.
Implementations